==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/DoubleValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DoubleValueChangedEventArgsDescription } from "./DoubleValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let DoubleValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DoubleValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DoubleValueChangedEventArgsDescriptionMetadata.a == null) {
                DoubleValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DoubleValueChangedEventArgsDescriptionMetadata.c(DoubleValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(DoubleValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(DoubleValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldValue", "Number:double");
            a.item("NewValue", "Number:double");
        }
        static d(a) {
            DoubleValueChangedEventArgsDescriptionMetadata.b(a);
            a.aa("DoubleValueChangedEventArgs", () => new DoubleValueChangedEventArgsDescription());
            a.z("DoubleValueChangedEventArgs", DoubleValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    DoubleValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DoubleValueChangedEventArgsDescriptionMetadata, 'DoubleValueChangedEventArgsDescriptionMetadata');
    DoubleValueChangedEventArgsDescriptionMetadata.a = null;
    return DoubleValueChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DoubleValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DoubleValueChangedEventArgsDescription } from "./DoubleValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let DoubleValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DoubleValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DoubleValueChangedEventArgsDescriptionMetadata.a == null) {
                DoubleValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DoubleValueChangedEventArgsDescriptionMetadata.c(DoubleValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(DoubleValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(DoubleValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldValue", "Number:double");
            a.item("NewValue", "Number:double");
        }
        static d(a) {
            DoubleValueChangedEventArgsDescriptionMetadata.b(a);
            a.ac("DoubleValueChangedEventArgs", () => new DoubleValueChangedEventArgsDescription());
            a.ab("DoubleValueChangedEventArgs", DoubleValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    DoubleValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DoubleValueChangedEventArgsDescriptionMetadata, 'DoubleValueChangedEventArgsDescriptionMetadata');
    DoubleValueChangedEventArgsDescriptionMetadata.a = null;
    return DoubleValueChangedEventArgsDescriptionMetadata;
})();
